@@ -41,10 +41,14 @@ sub get_youtube_list_info {
             die $res->status_line, ': ', $url if ! $res->is_success;
             my $content = $res->decoded_content;
             my $dom = Mojo::DOM->new( $content );
-            my $uploader = $dom->at( 'meta[itemprop="name"][content]' )->attr( 'content' );
+            my $uploader;
+            my $el_uploader = $dom->at( 'meta[itemprop="name"][content]' );
+            if ( $el_uploader ) {
+                $uploader = $el_uploader->attr( 'content' );
+            }
+            _parse_yt_list_html( $content, $uploader, $tmp );
             my $load_more_widget_html;
             my $more_button = $dom->at( 'button[class*="browse-items-load-more-button"][data-uix-load-more-href]' );
-            _parse_yt_list_html( $content, $uploader, $tmp );
             if ( $more_button ) {
                 $load_more_widget_html = $more_button->to_string;
             }
@@ -148,7 +152,11 @@ sub get_vimeo_list_info {
             my $res = $ua->get( $url );
             die $res->status_line, ': ', $url if ! $res->is_success;
             my $dom = Mojo::DOM->new( $res->decoded_content );
-            my $uploader = $dom->at( 'a[class="user"]' )->text;
+            my $uploader;
+            my $el_uploader = $dom->at( 'a[class="user"]' );
+            if ( $el_uploader ) {
+                $uploader = $el_uploader->text;
+            }
             $dom->find( 'div[id="browse_content"] > ol > li[id][data-position]' )
                 ->each(
                     sub {
