@@ -121,7 +121,6 @@ sub _menus {
             [ 'merged_in_files', "- Input files"       ],
         ],
         group_history => [
-            [ 'log_info',                  "- Logging"          ], # ### pod
             [ 'max_size_history',          "- Size history"     ],
             [ 'sort_history_by_timestamp', "- History sort"     ],
             [ 'enable_download_archive',   "- Download archive" ],
@@ -401,11 +400,6 @@ sub set_options {
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
-            elsif ( $choice eq "log_info" ) { # ###
-                my $prompt = 'Enable info-logging';
-                my $list = [ qw( no yes ) ];
-                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
-            }
             elsif ( $choice eq "max_size_history" ) {
                 my $prompt = 'Max size of history';
                 my $digits = 3;
